summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorZane Shelley <zshelle@us.ibm.com>2018-03-26 14:06:48 -0500
committerZane C. Shelley <zshelle@us.ibm.com>2018-03-29 10:30:41 -0400
commit42e4c422f63b24bc73d2ce3a0e9b086ccee75aee (patch)
tree40ca14f63710ced6cf5bf7bf62d2d678665eb3eb /src
parent0bd003abad5f2f6f388c0a3b69258e7614ff83a6 (diff)
downloadtalos-hostboot-42e4c422f63b24bc73d2ce3a0e9b086ccee75aee.tar.gz
talos-hostboot-42e4c422f63b24bc73d2ce3a0e9b086ccee75aee.zip
PRD: moved prdfCenMbaDataBundle.H to common code
In preparation of additional changes. Change-Id: I02ea8a40e602c974fc986deade7ca94ae5110d15 Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/56262 Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Reviewed-by: Benjamin J. Weisenbeck <bweisenb@us.ibm.com> Reviewed-by: Caleb N. Palmer <cnpalmer@us.ibm.com> Reviewed-by: Brian J. Stegmiller <bjs@us.ibm.com> Reviewed-by: Zane C. Shelley <zshelle@us.ibm.com> Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/56410 Tested-by: Jenkins OP Build CI <op-jenkins+hostboot@us.ibm.com> Tested-by: Jenkins OP HW <op-hw-jenkins+hostboot@us.ibm.com> Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com>
Diffstat (limited to 'src')
-rw-r--r--src/usr/diag/prdf/common/plat/mem/prdfCenMbaDataBundle.H (renamed from src/usr/diag/prdf/plat/mem/prdfCenMbaDataBundle.H)27
1 files changed, 21 insertions, 6 deletions
diff --git a/src/usr/diag/prdf/plat/mem/prdfCenMbaDataBundle.H b/src/usr/diag/prdf/common/plat/mem/prdfCenMbaDataBundle.H
index e2a03e85a..85ef296ed 100644
--- a/src/usr/diag/prdf/plat/mem/prdfCenMbaDataBundle.H
+++ b/src/usr/diag/prdf/common/plat/mem/prdfCenMbaDataBundle.H
@@ -1,11 +1,11 @@
/* IBM_PROLOG_BEGIN_TAG */
/* This is an automatically generated prolog. */
/* */
-/* $Source: src/usr/diag/prdf/plat/mem/prdfCenMbaDataBundle.H $ */
+/* $Source: src/usr/diag/prdf/common/plat/mem/prdfCenMbaDataBundle.H $ */
/* */
/* OpenPOWER HostBoot Project */
/* */
-/* Contributors Listed Below - COPYRIGHT 2017 */
+/* Contributors Listed Below - COPYRIGHT 2017,2018 */
/* [+] International Business Machines Corp. */
/* */
/* */
@@ -30,9 +30,14 @@
#include <prdfExtensibleChip.H>
// Platform includes
-#include <prdfMemTdCtlr.H>
#include <prdfPlatServices.H>
+#ifdef __HOSTBOOT_MODULE
+
+ #include <prdfMemTdCtlr.H>
+
+#endif
+
namespace PRDF
{
@@ -43,22 +48,26 @@ class MbaDataBundle : public DataBundle
/**
* @brief Constructor.
* @param i_mbaChip The MBA chip.
*/
- explicit MbaDataBundle( ExtensibleChip * i_mbaChip ) :
- iv_chip(i_mbaChip)
+ explicit MbaDataBundle( ExtensibleChip * i_chip ) :
+ iv_chip(i_chip)
{}
/** @brief Destructor. */
~MbaDataBundle()
{
+ #ifdef __HOSTBOOT_MODULE
delete iv_tdCtlr; iv_tdCtlr = nullptr;
+ #endif
}
// Don't allow copy or assignment.
MbaDataBundle( const MbaDataBundle & ) = delete;
const MbaDataBundle & operator=( const MbaDataBundle & ) = delete;
+ #ifdef __HOSTBOOT_MODULE
+
/** @return The Targeted Diagnostics controller. */
MemTdCtlr<TARGETING::TYPE_MBA> * getTdCtlr()
{
@@ -70,13 +79,19 @@ class MbaDataBundle : public DataBundle
return iv_tdCtlr;
}
+ #endif
+
private: // instance variables
/** The MBA chip associated with this data bundle. */
ExtensibleChip * const iv_chip;
+ #ifdef __HOSTBOOT_MODULE
+
/** The Targeted Diagnostics controller. */
MemTdCtlr<TARGETING::TYPE_MBA> * iv_tdCtlr = nullptr;
+
+ #endif
};
/**
OpenPOWER on IntegriCloud
@@ -43,22 +48,26 @@ class MbaDataBundle : public DataBundle
/**
* @brief Constructor.
- * @param i_mbaChip The MBA chip.
+ * @param i_chip The MBA chip.
*/